@@ -29,5 +29,5 @@ class BaseInitCommand(BaseCommand, abc.ABC):
         n = len(report)
         report_str = '\n'.join([f'- {name}' for name in report])
 
-        message = f'Successfully {self.action}d {n} {self.name}\n{report_str}'
+        message = f'Successfully {self.action}d {n} {self.name} to domain {app_config.domain}\n{report_str}'
         self.stdout.write(self.style.SUCCESS(message))
